@@ -1,5 +1,6 @@
-import os, json, re, pdb
+import os, json, re, pdb, importlib.util
 from os import path, listdir
+from .utils import printer
 
 class Config:
 
@@ -8,6 +9,7 @@ class Config:
     self.config_file_path = path.join(self.config_dir_path, "config.json")
     self.prompt_history_path = path.join(self.config_dir_path, "prompt_history")
     self.threads_dir_path = path.join(self.config_dir_path, "threads")
+    self.plugins_dir_path = path.join(self.config_dir_path, "plugins")
 
     if not path.exists(self.config_dir_path):
       os.makedirs(self.config_dir_path)
@@ -15,6 +17,9 @@ class Config:
     if not path.exists(self.threads_dir_path):
       os.mkdir(self.threads_dir_path)
 
+    if not path.exists(self.plugins_dir_path):
+      os.mkdir(self.plugins_dir_path)
+
     self.reload()
 
   def save(self):
@@ -81,8 +86,7 @@ class Config:
     thread_id = self.normalize_thread_id(thread_id)
     return {
       "id": thread_id,
-      # "conversation_id": "",
-      # "previous_conversation_id": "",
+      "mode": "",
       'state': {},
       "history": [],
     }
@@ -102,3 +106,17 @@ class Config:
     threads.sort(reverse=True)
 
     return [thread_id for _, thread_id in threads]
+
+  def load_plugins(self):
+    files = os.listdir(self.plugins_dir_path)
+    for file in files:
+      file_path = path.join(self.plugins_dir_path, file)
+      if not file_path.endswith('.py'):
+        continue
+      try:
+        spec = importlib.util.spec_from_file_location('plugins', file_path)
+        module = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(module)
+      except Exception as e:
+        printer.exception(e)
+        continue
