@@ -22,12 +22,16 @@ class BaseMode:
 
   title = ''
   visible = True
+  loader_latency=1.5
 
   seed = ''
 
   def __init__(self, state={}):
     pass
 
+  def get_title(self):
+    return self.title
+
   def ask(self, text):
     yield ''
 
